summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
Diffstat (limited to 'lib')
-rw-r--r--lib/fs.js8
-rw-r--r--lib/internal/fs/watchers.js19
2 files changed, 14 insertions, 13 deletions
diff --git a/lib/fs.js b/lib/fs.js
index d5c7ea70d8..1b3df1119f 100644
--- a/lib/fs.js
+++ b/lib/fs.js
@@ -1342,10 +1342,10 @@ function watch(filename, options, listener) {
if (!watchers)
watchers = require('internal/fs/watchers');
const watcher = new watchers.FSWatcher();
- watcher.start(filename,
- options.persistent,
- options.recursive,
- options.encoding);
+ watcher[watchers.kFSWatchStart](filename,
+ options.persistent,
+ options.recursive,
+ options.encoding);
if (listener) {
watcher.addListener('change', listener);
diff --git a/lib/internal/fs/watchers.js b/lib/internal/fs/watchers.js
index bde07cfdc5..4dfa83c3b2 100644
--- a/lib/internal/fs/watchers.js
+++ b/lib/internal/fs/watchers.js
@@ -25,6 +25,8 @@ const assert = require('internal/assert');
const kOldStatus = Symbol('kOldStatus');
const kUseBigint = Symbol('kUseBigint');
+const kFSWatchStart = Symbol('kFSWatchStart');
+
function emitStop(self) {
self.emit('stop');
}
@@ -135,18 +137,16 @@ function FSWatcher() {
Object.setPrototypeOf(FSWatcher.prototype, EventEmitter.prototype);
Object.setPrototypeOf(FSWatcher, EventEmitter);
-
-// FIXME(joyeecheung): this method is not documented.
// At the moment if filename is undefined, we
// 1. Throw an Error if it's the first time .start() is called
// 2. Return silently if .start() has already been called
// on a valid filename and the wrap has been initialized
// 3. Return silently if the watcher has already been closed
// This method is a noop if the watcher has already been started.
-FSWatcher.prototype.start = function(filename,
- persistent,
- recursive,
- encoding) {
+FSWatcher.prototype[kFSWatchStart] = function(filename,
+ persistent,
+ recursive,
+ encoding) {
if (this._handle === null) { // closed
return;
}
@@ -202,5 +202,6 @@ Object.defineProperty(FSEvent.prototype, 'owner', {
module.exports = {
FSWatcher,
- StatWatcher
+ StatWatcher,
+ kFSWatchStart
};
@@ -135,18 +137,16 @@ function FSWatcher() {
// At the moment if filename is undefined, we
-// 1. Throw an Error if it's the first time .start() is called
-// 2. Return silently if .start() has already been called
+// 1. Throw an Error if it's the first time Symbol('kFSWatchStart') is called
+// 2. Return silently if Symbol('kFSWatchStart') has already been called
// on a valid filename and the wrap has been initialized
// 3. Return silently if the watcher has already been closed